data("airquality")
data("attenu")
data("clothianidin")
data("faithful")
data("mtcars")
data("precip")
data("sleep")
data("trees")
data("warpbreaks")
data("women")
set.seed(10358)
